<?php

class ControllerModuleSpecialLabel extends Controller {

    private $error = array();

    public function index() {
        $this->load->language('module/special_label');
        $this->load->model('module/special_label');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
            $post = array();
            $post['special_label_enabled'] = $this->request->post['special_label_enabled'];
            $post['special_label_style'] = $this->request->post['special_label_style'];
            $post['special_label_default_style'] = $this->config->get('special_label_default_style');
            $post['special_label_show_percentage'] = $this->request->post['special_label_show_percentage'];
            $post['special_label_show_sign'] = $this->request->post['special_label_show_sign'];

            $this->model_setting_setting->editSetting('special_label', $post);

            $this->model_module_special_label->updateLabels($this->request->post['special_label_label']);

            $this->session->data['success'] = $this->language->get('text_success');
            $this->redirect($this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'));
        }

        $this->data = array();
        $this->data['heading_title'] = $this->language->get('heading_title');

        $this->data['text_edit'] = $this->language->get('text_edit');
        $this->data['text_enabled'] = $this->language->get('text_enabled');
        $this->data['text_disabled'] = $this->language->get('text_disabled');
        $this->data['text_yes'] = $this->language->get('text_yes');
        $this->data['text_no'] = $this->language->get('text_no');

        $this->data['entry_status'] = $this->language->get('entry_status');
        $this->data['entry_special_label'] = $this->language->get('entry_special_label');
        $this->data['entry_style'] = $this->language->get('entry_style');
        $this->data['entry_css_nodes'] = $this->language->get('entry_css_nodes');
        $this->data['entry_css_nodes_content'] = $this->language->get('entry_css_nodes_content');
        $this->data['entry_load_default_style'] = $this->language->get('entry_load_default_style');
        $this->data['entry_show_sign'] = $this->language->get('entry_show_sign');
        $this->data['entry_show_percentage'] = $this->language->get('entry_show_percentage');
        $this->data['entry_placeholder'] = $this->language->get('entry_placeholder');
        $this->data['entry_confirm_default_style_loading'] = $this->language->get('entry_confirm_default_style_loading');

        $this->data['button_save'] = $this->language->get('button_save');
        $this->data['button_cancel'] = $this->language->get('button_cancel');



        if (isset($this->error['warning'])) {
            $this->data['error_warning'] = $this->error['warning'];
        } else {
            $this->data['error_warning'] = '';
        }

        if (isset($this->error['label'])) {
            $this->data['error_label'] = $this->error['label'];
        } else {
            $this->data['error_label'] = '';
        }

        $this->data['breadcrumbs'] = array();

        $this->data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/dashboard', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => false
        );

        $this->data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_module'),
            'href' => $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        $this->data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('module/special_label', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        $this->data['action'] = $this->url->link('module/special_label', 'token=' . $this->session->data['token'], 'SSL');

        $this->data['cancel'] = $this->url->link('extension/module', 'token=' . $this->session->data['token'], 'SSL');

        // status
        if (isset($this->request->post['special_label_enabled'])) {
            $this->data['special_label_enabled'] = $this->request->post['special_label_enabled'];
        } else {
            $this->data['special_label_enabled'] = $this->config->get('special_label_enabled');
        }

        // label
        if (isset($this->request->post['special_label_label'])) {
            $this->data['special_label_label'] = $this->request->post['special_label_label'];
        } else {
            $this->data['special_label_label'] = $this->model_module_special_label->getLabels();
        }

        // style
        if (isset($this->request->post['special_label_style'])) {
            $this->data['special_label_style'] = $this->request->post['special_label_style'];
        } else {
            $this->data['special_label_style'] = $this->config->get('special_label_style');
        }

        // show_percentage
        if (isset($this->request->post['special_label_show_percentage'])) {
            $this->data['special_label_show_percentage'] = $this->request->post['special_label_show_percentage'];
        } else {
            $this->data['special_label_show_percentage'] = $this->config->get('special_label_show_percentage');
        }

        // show_sign
        if (isset($this->request->post['special_label_show_sign'])) {
            $this->data['special_label_show_sign'] = $this->request->post['special_label_show_sign'];
        } else {
            $this->data['special_label_show_sign'] = $this->config->get('special_label_show_sign');
        }

        // default_style
        $this->data['special_label_default_style'] = $this->config->get('special_label_default_style');

        $this->template = 'module/special_label.tpl';
        $this->children = array(
            'common/header',
            'common/footer'
        );

        $this->response->setOutput($this->render());
    }

    protected function validate() {
        foreach ($this->request->post['special_label_label'] as $key => $label) {
            if (trim($label['label']) == "") {
                $this->error['label'][$key] = $this->language->get('error_empty_line');
            }
        }
        if (!$this->user->hasPermission('modify', 'module/special_label')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }


        return !$this->error;
    }

    public function install() {
        $this->load->model('setting/setting');
        $post = array();
        $post['special_label_enabled'] = "1";
        $post['special_label_show_sign'] = "0";
        $post['special_label_show_percentage'] = "1";
        $post['special_label_enabled'] = "1";
        $post['special_label_style'] = $post['special_label_default_style'] = ".box-product > div,
    .product-grid > div,
    .product-list >div .left
    {
        overflow: hidden;
        position: relative;
        padding-left: 10px;
    }

    .product-discount{
        color: white;
        position: absolute;
        text-transform: uppercase;
        text-align: center;
        border: 3px white double;
        width: 200px;
        background-color: #23a1d1;
        margin-left: -74px;
        margin-top: 15px;
        -ms-transform: rotate(-45deg); 
        -webkit-transform: rotate(-45deg); 
        transform: rotate(-45deg);
        z-index: 2;
        height: 14px;
    }

    .product-discount p{
        padding-top: 1px;
        width: 120px;
        margin: auto;
        font-size: 11px;
        margin-left: 34px;
    }

    .product-discount:before{
        -ms-transform: rotate(45deg);
        -webkit-transform: rotate(45deg);
        transform: rotate(45deg);
        content: '*';
        color: transparent;
        position: absolute;
        z-index: -1;
        border-left: 10px solid transparent;
        border-bottom: 5px solid transparent;
        border-top: 10px solid transparent;
        border-right: 10px solid #176B8C;
        height: 0;
        width: 0;
        margin-left: -73px;
        margin-top: 8px;
    }";

        $this->model_setting_setting->editSetting('special_label', $post);
        $this->load->model('module/special_label');
        $this->model_module_special_label->createSpecialLabelTable();
    }

    public function uninstall() {
        $this->load->model('module/special_label');
        $this->model_module_special_label->deleteSpecialLabelTable();
    }

}
